==> gwasrapidd_0.99.14.tar.gz: gwasrapidd/tests/testthat/mocks/gc/a/0/snps.R <==
structure(list(url = "gc/a/0/snps", status_code = 404L, headers = structure(list(
    server = "Apache-Coyote/1.1", `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
    `strict-transport-security` = "max-age=0", date = "Thu, 25 Nov 2021 22:49:26 GMT", 
    `x-application-context` = "application", expires = "0", `x-xss-protection` = "1; mode=block", 
    pragma = "no-cache", `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
    `x-frame-options` = "DENY"), class = c("insensitive", "list"
)), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
    headers = structure(list(server = "Apache-Coyote/1.1", `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
        `strict-transport-security` = "max-age=0", date = "Thu, 25 Nov 2021 22:49:26 GMT", 
        `x-application-context` = "application", expires = "0", 
        `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
        `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
        `x-frame-options` = "DENY"), class = c("insensitive", 
    "list")))), cookies = structure(list(domain = logical(0), 
    flag = logical(0), path = logical(0), secure = logical(0), 
    expiration = structure(numeric(0), class = c("POSIXct", "POSIXt"
    )), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = raw(0), date = structure(1637880566, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 2.6e-05, 
    connect = 2.6e-05, pretransfer = 6.3e-05, starttransfer = 0.057675, 
    total = 0.057697)), class = "response")

==> gwasrapidd_0.99.17.tar.gz: gwasrapidd/tests/testthat/mocks/gc/a/0/snps.R <==
structure(list(url = "gc/a/0/snps", status_code = 404L, headers = structure(list(
    server = "Apache-Coyote/1.1", `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
    `strict-transport-security` = "max-age=0", date = "Sun, 04 Jun 2023 15:35:43 GMT", 
    `x-application-context` = "application", expires = "0", `x-xss-protection` = "1; mode=block", 
    pragma = "no-cache", `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
    `x-frame-options` = "DENY"), class = c("insensitive", "list"
)), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
    headers = structure(list(server = "Apache-Coyote/1.1", `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
        `strict-transport-security` = "max-age=0", date = "Sun, 04 Jun 2023 15:35:43 GMT", 
        `x-application-context` = "application", expires = "0", 
        `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
        `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
        `x-frame-options` = "DENY"), class = c("insensitive", 
    "list")))), cookies = structure(list(domain = logical(0), 
    flag = logical(0), path = logical(0), secure = logical(0), 
    expiration = structure(numeric(0), class = c("POSIXct", "POSIXt"
    )), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = raw(0), date = structure(1685892943, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 0.070921, 
    connect = 0.121108, pretransfer = 0.224255, starttransfer = 0.282982, 
    total = 0.283705)), class = "response")
